vdoc.settings package | vdoc 0.19.0 documentation

Skip to content

# vdoc.settings package

## Module contents

Contains the settings definition.

class vdoc.settings.VDocSettings(_case_sensitive=None, _nested_model_default_partial_update=None, _env_prefix=None, _env_file=PosixPath('.'), _env_file_encoding=None, _env_ignore_empty=None, _env_nested_delimiter=None, _env_nested_max_split=None, _env_parse_none_str=None, _env_parse_enums=None, _cli_prog_name=None, _cli_parse_args=None, _cli_settings_source=None, _cli_parse_none_str=None, _cli_hide_none_type=None, _cli_avoid_json=None, _cli_enforce_required=None, _cli_use_class_docs_for_groups=None, _cli_exit_on_error=None, _cli_prefix=None, _cli_flag_prefix_char=None, _cli_implicit_flags=None, _cli_ignore_unknown_args=None, _cli_kebab_case=None, _cli_shortcuts=None, _secrets_dir=None, **values)

  Bases: `BaseSettings`

  The vdoc settings.

  api_password: `bytes`
  api_username: `bytes`
  bind_address: `str`
  bind_port: `int`
  docs_dir: `Path`
  model_config: ClassVar[SettingsConfigDict] = {'arbitrary_types_allowed': True, 'case_sensitive': False, 'cli_avoid_json': False, 'cli_enforce_required': False, 'cli_exit_on_error': True, 'cli_flag_prefix_char': '-', 'cli_hide_none_type': False, 'cli_ignore_unknown_args': False, 'cli_implicit_flags': False, 'cli_kebab_case': False, 'cli_parse_args': None, 'cli_parse_none_str': None, 'cli_prefix': '', 'cli_prog_name': None, 'cli_shortcuts': None, 'cli_use_class_docs_for_groups': False, 'enable_decoding': True, 'env_file': None, 'env_file_encoding': None, 'env_ignore_empty': False, 'env_nested_delimiter': None, 'env_nested_max_split': None, 'env_parse_enums': None, 'env_parse_none_str': 'None', 'env_prefix': 'VDOC_', 'extra': 'forbid', 'json_file': None, 'json_file_encoding': None, 'nested_model_default_partial_update': False, 'protected_namespaces': ('model_validate', 'model_dump', 'settings_customise_sources'), 'secrets_dir': None, 'toml_file': None, 'validate_default': True, 'yaml_config_section': None, 'yaml_file': None, 'yaml_file_encoding': None}

    Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].

  project_categories: `list`[`ProjectCategory`]
  project_category_mapping: `dict`[`str`, `str`]
  project_display_name_mapping: `dict`[`str`, `str`]
  validate_model()

    Validates the model.

    The following checks are performed:

    - Ensures that all category IDs in project_categories are unique.

    - Ensures that all category names in project_categories are unique.

    - Ensures that all categories in project_category_mapping are defined in project_categories.

    Raises:

      ValueError – If any check fails.

    Returns:

      The validated model.

    Return type:

      Self

vdoc.models.plugins package
Getting Started with vdoc